@@ -9,11 +9,11 @@ import (
 	exutil "github.com/openshift/origin/test/extended/util"
 )
 
-var _ = g.Describe("[cli]oc rsh[Conformance]", func() {
+var _ = g.Describe("[sig-cli] oc rsh", func() {
 	defer g.GinkgoRecover()
 
 	var (
-		oc                     = exutil.NewCLI("oc-rsh", exutil.KubeConfigPath())
+		oc                     = exutil.NewCLI("oc-rsh")
 		multiContainersFixture = exutil.FixturePath("testdata", "cli", "pod-with-two-containers.yaml")
 		podsLabel              = exutil.ParseLabelsOrDie("name=hello-centos")
 	)
